@@ -10,11 +10,11 @@ structure(list(x = c(-1.01157732356344, -0.844512148091014, -0.723389895873506,
 0.0920857017927417, 0.0212505465675558, -0.0826410144293835, 
 -0.0873633581110625, 0.0684739833843463, 0.517096633143857, 0.75321381722781, 
 0.894884127678181)), .Names = c("x", "y"))
-library(Design)
+library(rms)
 dd <- datadist(as.data.frame(z)); options(datadist='dd')
 f <- ols(y ~ rcs(x,5), data=z)
 par(mfrow=c(1,2))
-plot(f)
+plot(Predict(f))
 abline(v=c(-.1772,.31375))
 points(z)
 xx <- seq(-1,1,length=1000)
@@ -24,7 +24,7 @@ plot(xx[-1], diff(g(xx)))
 abline(h=0)
 par(mfrow=c(1,1))
 
-plot(f)
+plot(Predict(f))
 turns <- formals(h)$turns
 abline(v=turns)
 
